==> mgb-0.5.4.7-de.zip: settings.php <==
<?php
	/*
	MGB 0.5.4.7
	Copyright (C) 2004 - 2007  Juergen Grueneisl

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	*/

        require "config.php";

        $sql="SELECT * FROM $db[settings]";
        $link=mysql_connect($db[host], $db[user], $db[password]) or die ("Keine Verbindung zur Datenbank mglich. Prfen Sie die Zugangsdaten.");
        mysql_select_db($db[dbname], $link) or die ("Datenbankfehler");
        $result=mysql_query($sql, $link) or die ("MySQL Fehler");

        for($i=0;$i<mysql_num_rows($result);$i++)
         	{
		$setting[$i]=mysql_fetch_array($result);
		}

        for($i=0;$i<count($setting);$i++)
		{
                $settings['ueberschrift'] = $setting[$i][ueberschrift];
                $settings['ueberschriftgroesse'] = $setting[$i][ueberschriftgroesse];
                $settings['ueberschriftfarbe'] = $setting[$i][ueberschriftfarbe];
                $settings['hpname'] = $setting[$i][hpname];
                $settings['hpadresse'] = $setting[$i][hpadresse];
                $settings['gbpfad'] = $setting[$i][gbpfad];
                $settings['adminemail'] = $setting[$i][adminemail];
                $settings['autor'] = $setting[$i][autor];
                $settings['keywords'] = $setting[$i][keywords];
		$settings['description'] = $setting[$i][description];
                $settings['moderated'] = $setting[$i][moderated];
                $settings['howtoopenadminwindow'] = $setting[$i][howtoopenadminwindow];
                $settings['spam'] = $setting[$i][spam];
                $settings['smilies'] = $setting[$i][smilies];
                $settings['bbcodes'] = $setting[$i][bbcodes];
                $settings['showgbinfo'] = $setting[$i][showgbinfo];
                $settings['zensur'] = $setting[$i][zensur];
                $settings['schriftart'] = $setting[$i][schriftart];
                $settings['schriftfarbe'] = $setting[$i][schriftfarbe];
                $settings['schriftfarbe_fehler'] = $setting[$i][schriftfarbe_fehler];
                $settings['schriftfarbe_name'] = $setting[$i][schriftfarbe_name];
                $settings['schriftgroesse'] = $setting[$i][schriftgroesse];
                $settings['hintergrundfarbe'] = $setting[$i][hintergrundfarbe];
                $settings['hintergrundbild'] = $setting[$i][hintergrundbild];
                $settings['rahmen_titelhintergrund'] = $setting[$i][rahmen_titelhintergrund];
                $settings['rahmen_hintergrundfarbe'] = $setting[$i][rahmen_hintergrundfarbe];
                $settings['rahmen_randfarbe'] = $setting[$i][rahmen_randfarbe];
                $settings['rahmen_breite'] = $setting[$i][rahmen_breite];
                $settings['rahmen_randbreite'] = $setting[$i][rahmen_randbreite];
                $settings['eintrag_hintergrundfarbe'] = $setting[$i][eintrag_hintergrundfarbe];
                $settings['eintrag_randfarbe'] = $setting[$i][eintrag_randfarbe];
                $settings['eintrag_breite'] = $setting[$i][eintrag_breite];
                $settings['eintrag_randbreite'] = $setting[$i][eintrag_randbreite];
                $settings['linkfarbe'] = $setting[$i][linkfarbe];
                $settings['linkfarbeaktiv'] = $setting[$i][linkfarbeaktiv];
                $settings['linkfarbebesucht'] = $setting[$i][linkfarbebesucht];
                $settings['linkfarbehover'] = $setting[$i][linkfarbehover];
                $settings['linkstyle'] = $setting[$i][linkstyle];
                $settings['eingabehintergrundfarbe'] = $setting[$i][eingabehintergrundfarbe];
                $settings['eingaberandfarbe'] = $setting[$i][eingaberandfarbe];
                $settings['eingabetextfarbe'] = $setting[$i][eingabetextfarbe];
                $settings['eingaberandbreite'] = $setting[$i][eingaberandbreite];
                $settings['sendemailuser'] = $setting[$i][sendemailuser];
                $settings['sendemailuserfrei'] = $setting[$i][sendemailuserfrei];
                $settings['sendemail'] = $setting[$i][sendemail];
                $settings['passwort'] = $setting[$i][passwort];
                $settings['adminalert'] = $setting[$i][adminalert];
                $settings['adminalerttries'] = $setting[$i][adminalerttries];
		$settings['cookie'] = $setting[$i][cookie];
		$settings['captcha'] = $setting[$i][captcha];
		$settings['ipsperre'] = $setting[$i][ipsperre];
                }

                // CSS f&uuml;r Textfelder und Schaltfl&auml;chen
                $settings['inputtextstyle'] = "background-color:".$settings['eingabehintergrundfarbe'].";color:".$settings['eingabetextfarbe'].";border:".$settings['eingaberandbreite']."px solid ".$settings['eingaberandfarbe'].";";

                // Allgemeines CSS
                $css="<style type='text/css'>\n";
                $css.="<!--\n";
                if($settings['linkstyle']=="normal")
                         {
                         $decoration="}\n";
                         }
                 elseif($settings['linkstyle']=="none")
                         {
                         $decoration="text-decoration:none;}\n";
                         }
                 elseif($settings['linkstyle']=="overline")
                         {
                         $decoration="text-decoration:overline;}\n";
                         }
                $css.="a:link{color:".$settings['linkfarbe'].";".$decoration;
		$css.="a:visited{color:".$settings['linkfarbebesucht'].";".$decoration;
		$css.="a:hover{color:".$settings['linkfarbehover'].";}\n";
		$css.="a:active{color:".$settings['linkfarbeaktiv'].";}\n";
                $css.="table.rahmen\n";
		$css.="{\n";
		$css.="border:".$settings['rahmen_randbreite']."px solid ".$settings['rahmen_randfarbe'].";\n";
                $css.="width:".$settings['rahmen_breite']."px;\n";
                $css.="}\n";
                $css.="td.rahmen_titel\n";
		$css.="{\n";
		$css.="border:none;\n";
                $css.="background-color:".$settings['rahmen_titelhintergrund'].";\n";
                $css.="}\n";
                $css.="td.rahmen_eintraege\n";
		$css.="{\n";
		$css.="border:none;\n";
                $css.="background-color:".$settings['rahmen_hintergrundfarbe'].";\n";
                $css.="}\n";
                $css.="table.eintraege\n";
		$css.="{\n";
		$css.="border:".$settings['eintrag_randbreite']."px solid ".$settings['eintrag_randfarbe'].";\n";
                $css.="background-color:".$settings['eintrag_hintergrundfarbe'].";\n";
                $css.="width:".$settings['eintrag_breite']."%;\n";
                $css.="}\n";
		$css.="td.eintraege\n";
		$css.="{\n";
		$css.="border:".$settings['eintrag_randbreite']."px solid ".$settings['eintrag_randfarbe'].";\n";
		$css.="}\n";
                $css.="font\n";
                $css.="{\n";
                $css.="font-size:".$settings['schriftgroesse']."px;\n";
                $css.="font-family:".$settings['schriftart'].";\n";
                $css.="color:".$settings['schriftfarbe'].";\n";
                $css.="}\n";
                $css.="font.copyright\n";
                $css.="{\n";
                $css.="font-size:10px;\n";
                $css.="font-family:".$settings['schriftart'].";\n";
                $css.="color:".$settings['schriftfarbe'].";\n";
                $css.="}\n";
                $css.="font.ueberschrift\n";
                $css.="{\n";
                $css.="font-size:".$settings['ueberschriftgroesse']."px;\n";
                $css.="font-family:".$settings['schriftart'].";\n";
                $css.="color:".$settings['ueberschriftfarbe'].";\n";
                $css.="}\n";
                $css.="font.fehler\n";
                $css.="{\n";
                $css.="font-size:".$settings['schriftgroesse']."px;\n";
                $css.="font-family:".$settings['schriftart'].";\n";
                $css.="color:".$settings['schriftfarbe_fehler'].";\n";
                $css.="}\n";
                $css.="font.name\n";
                $css.="{\n";
                $css.="font-size:".$settings['schriftgroesse']."px;\n";
                $css.="font-family:".$settings['schriftart'].";\n";
                $css.="color:".$settings['schriftfarbe_name'].";\n";
                $css.="}\n";
                $css.="body\n";
                $css.="{\n";
                if($settings['hintergrundbild'])
                 	{
                        $css.="background-image: url(".$settings['hintergrundbild'].");\n";
                        }
                else
                 	{
                 	$css.="background-color:".$settings['hintergrundfarbe'].";\n";
                        }
                $css.="}\n";
		$css.="//-->\n";
                $css.="</style>"
?>

==> mgb-0.5.4.8-de.zip: settings.php <==
<?php
	/*
	MGB 0.5.4.8
	Copyright (C) 2004 - 2007  Juergen Grueneisl

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	*/

        require "config.php";

        $sql="SELECT * FROM $db[settings]";
        $link=mysql_connect($db[host], $db[user], $db[password]) or die ("(settings.php) Error: ".mysql_error());
        mysql_select_db($db[dbname], $link) or die ("(settings.php) Error: ".mysql_error());
        $result=mysql_query($sql, $link) or die ("(settings.php) Error: ".mysql_error());

        for($i=0;$i<mysql_num_rows($result);$i++)
         	{
		$setting[$i]=mysql_fetch_array($result);
		}

        for($i=0;$i<count($setting);$i++)
		{
                $settings['ueberschrift'] = $setting[$i][ueberschrift];
                $settings['ueberschriftgroesse'] = $setting[$i][ueberschriftgroesse];
                $settings['ueberschriftfarbe'] = $setting[$i][ueberschriftfarbe];
                $settings['hpname'] = $setting[$i][hpname];
                $settings['hpadresse'] = $setting[$i][hpadresse];
                $settings['gbpfad'] = $setting[$i][gbpfad];
                $settings['adminemail'] = $setting[$i][adminemail];
                $settings['autor'] = $setting[$i][autor];
                $settings['keywords'] = $setting[$i][keywords];
		$settings['description'] = $setting[$i][description];
                $settings['moderated'] = $setting[$i][moderated];
                $settings['howtoopenadminwindow'] = $setting[$i][howtoopenadminwindow];
                $settings['spam'] = $setting[$i][spam];
                $settings['smilies'] = $setting[$i][smilies];
                $settings['bbcodes'] = $setting[$i][bbcodes];
                $settings['showgbinfo'] = $setting[$i][showgbinfo];
                $settings['zensur'] = $setting[$i][zensur];
                $settings['schriftart'] = $setting[$i][schriftart];
                $settings['schriftfarbe'] = $setting[$i][schriftfarbe];
                $settings['schriftfarbe_fehler'] = $setting[$i][schriftfarbe_fehler];
                $settings['schriftfarbe_name'] = $setting[$i][schriftfarbe_name];
                $settings['schriftgroesse'] = $setting[$i][schriftgroesse];
                $settings['hintergrundfarbe'] = $setting[$i][hintergrundfarbe];
                $settings['hintergrundbild'] = $setting[$i][hintergrundbild];
                $settings['rahmen_titelhintergrund'] = $setting[$i][rahmen_titelhintergrund];
                $settings['rahmen_hintergrundfarbe'] = $setting[$i][rahmen_hintergrundfarbe];
                $settings['rahmen_randfarbe'] = $setting[$i][rahmen_randfarbe];
                $settings['rahmen_breite'] = $setting[$i][rahmen_breite];
                $settings['rahmen_randbreite'] = $setting[$i][rahmen_randbreite];
                $settings['eintrag_hintergrundfarbe'] = $setting[$i][eintrag_hintergrundfarbe];
                $settings['eintrag_randfarbe'] = $setting[$i][eintrag_randfarbe];
                $settings['eintrag_breite'] = $setting[$i][eintrag_breite];
                $settings['eintrag_randbreite'] = $setting[$i][eintrag_randbreite];
                $settings['linkfarbe'] = $setting[$i][linkfarbe];
                $settings['linkfarbeaktiv'] = $setting[$i][linkfarbeaktiv];
                $settings['linkfarbebesucht'] = $setting[$i][linkfarbebesucht];
                $settings['linkfarbehover'] = $setting[$i][linkfarbehover];
                $settings['linkstyle'] = $setting[$i][linkstyle];
                $settings['eingabehintergrundfarbe'] = $setting[$i][eingabehintergrundfarbe];
                $settings['eingaberandfarbe'] = $setting[$i][eingaberandfarbe];
                $settings['eingabetextfarbe'] = $setting[$i][eingabetextfarbe];
                $settings['eingaberandbreite'] = $setting[$i][eingaberandbreite];
                $settings['sendemailuser'] = $setting[$i][sendemailuser];
                $settings['sendemailuserfrei'] = $setting[$i][sendemailuserfrei];
                $settings['sendemail'] = $setting[$i][sendemail];
                $settings['passwort'] = $setting[$i][passwort];
                $settings['adminalert'] = $setting[$i][adminalert];
                $settings['adminalerttries'] = $setting[$i][adminalerttries];
		$settings['cookie'] = $setting[$i][cookie];
		$settings['captcha'] = $setting[$i][captcha];
		$settings['ipsperre'] = $setting[$i][ipsperre];
                }

                // CSS f&uuml;r Textfelder und Schaltfl&auml;chen
                $settings['inputtextstyle'] = "background-color:".$settings['eingabehintergrundfarbe'].";color:".$settings['eingabetextfarbe'].";border:".$settings['eingaberandbreite']."px solid ".$settings['eingaberandfarbe'].";";

                // Allgemeines CSS
                $css="<style type='text/css'>\n";
                $css.="<!--\n";
                if($settings['linkstyle']=="normal")
                         {
                         $decoration="}\n";
                         }
                 elseif($settings['linkstyle']=="none")
                         {
                         $decoration="text-decoration:none;}\n";
                         }
                 elseif($settings['linkstyle']=="overline")
                         {
                         $decoration="text-decoration:overline;}\n";
                         }
                $css.="a:link{color:".$settings['linkfarbe'].";".$decoration;
		$css.="a:visited{color:".$settings['linkfarbebesucht'].";".$decoration;
		$css.="a:hover{color:".$settings['linkfarbehover'].";}\n";
		$css.="a:active{color:".$settings['linkfarbeaktiv'].";}\n";
                $css.="table.rahmen\n";
		$css.="{\n";
		$css.="border:".$settings['rahmen_randbreite']."px solid ".$settings['rahmen_randfarbe'].";\n";
                $css.="width:".$settings['rahmen_breite']."px;\n";
                $css.="}\n";
                $css.="td.rahmen_titel\n";
		$css.="{\n";
		$css.="border:none;\n";
                $css.="background-color:".$settings['rahmen_titelhintergrund'].";\n";
                $css.="}\n";
                $css.="td.rahmen_eintraege\n";
		$css.="{\n";
		$css.="border:none;\n";
                $css.="background-color:".$settings['rahmen_hintergrundfarbe'].";\n";
                $css.="}\n";
                $css.="table.eintraege\n";
		$css.="{\n";
		$css.="border:".$settings['eintrag_randbreite']."px solid ".$settings['eintrag_randfarbe'].";\n";
                $css.="background-color:".$settings['eintrag_hintergrundfarbe'].";\n";
                $css.="width:".$settings['eintrag_breite']."%;\n";
                $css.="}\n";
		$css.="td.eintraege\n";
		$css.="{\n";
		$css.="border:".$settings['eintrag_randbreite']."px solid ".$settings['eintrag_randfarbe'].";\n";
		$css.="}\n";
                $css.="font\n";
                $css.="{\n";
                $css.="font-size:".$settings['schriftgroesse']."px;\n";
                $css.="font-family:".$settings['schriftart'].";\n";
                $css.="color:".$settings['schriftfarbe'].";\n";
                $css.="}\n";
                $css.="font.copyright\n";
                $css.="{\n";
                $css.="font-size:10px;\n";
                $css.="font-family:".$settings['schriftart'].";\n";
                $css.="color:".$settings['schriftfarbe'].";\n";
                $css.="}\n";
                $css.="font.ueberschrift\n";
                $css.="{\n";
                $css.="font-size:".$settings['ueberschriftgroesse']."px;\n";
                $css.="font-family:".$settings['schriftart'].";\n";
                $css.="color:".$settings['ueberschriftfarbe'].";\n";
                $css.="}\n";
                $css.="font.fehler\n";
                $css.="{\n";
                $css.="font-size:".$settings['schriftgroesse']."px;\n";
                $css.="font-family:".$settings['schriftart'].";\n";
                $css.="color:".$settings['schriftfarbe_fehler'].";\n";
                $css.="}\n";
                $css.="font.name\n";
                $css.="{\n";
                $css.="font-size:".$settings['schriftgroesse']."px;\n";
                $css.="font-family:".$settings['schriftart'].";\n";
                $css.="color:".$settings['schriftfarbe_name'].";\n";
                $css.="}\n";
                $css.="body\n";
                $css.="{\n";
                if($settings['hintergrundbild'])
                 	{
                        $css.="background-image: url(".$settings['hintergrundbild'].");\n";
                        }
                else
                 	{
                 	$css.="background-color:".$settings['hintergrundfarbe'].";\n";
                        }
                $css.="}\n";
		$css.="//-->\n";
                $css.="</style>"
?>
